#
# spec file for package haxe
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global commit_ocamllibs ab5be31c6dd1fcd761c2ba16c5d767bcf6792490
%global commit_haxelib a494d8be523e26fcf875e2c33915808dc221e17a

Name:           haxe
Version:        3.4.7
Release:        lp150.1.1
Summary:        Multiplatform programming language
License:        GPL-2.0+ and MIT
Group:          Development/Languages/Other
# As described in http://haxe.org/foundation/open-source.html:
#   * The Haxe Compiler - GPLv2+
#   * The Haxe Standard Library - MIT
Url:            https://haxe.org/
Source0:        https://github.com/HaxeFoundation/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/HaxeFoundation/ocamllibs/archive/%{commit_ocamllibs}.tar.gz#/ocamllibs-%{commit_ocamllibs}.tar.gz
Source2:        https://github.com/HaxeFoundation/haxelib/archive/%{commit_haxelib}.tar.gz#/haxelib-%{commit_haxelib}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  help2man
BuildRequires:  neko-devel >= 2.2.0
BuildRequires:  neko >= 2.2.0
BuildRequires:  ocaml >= 4.02.3
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pcre-devel-static
BuildRequires:  cmake
Requires:       neko >= 2.2.0

%description
Haxe is a high-level multiplatform programming language and compiler
that can produce applications and source code for many different
platforms from a single code-base. The Haxe compiler can compile Haxe
source code to Adobe Flash SWF files, ActionScript 3, JavaScript,
C++, PHP, C#, Java, Python, Lua, and Neko VM binary files.

%prep
%setup -q
pushd libs && tar -xf %{SOURCE1} --strip-components=1 && popd
pushd extra/haxelib_src && tar -xf %{SOURCE2} --strip-components=1 && popd

%build
# note that the Makefile does not support parallel building

# Haxe 3.4.* is not safe-string compatible.
export OCAMLPARAM="safe-string=0,_"

# Check to see if ocamlopt exists. If not, bytecompile everything.
# It is because ocamlopt may be missing in some architectures.
command -v ocamlopt && make libs haxe || make libs haxe BYTECODE=1

# Compile haxelib
pushd extra/haxelib_src && \
%cmake && \
make %{?_smp_mflags} && \
cp haxelib ../../../haxelib
popd

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{name}

cp -p haxe %{buildroot}%{_bindir}
cp -p haxelib %{buildroot}%{_bindir}
cp -rfp std %{buildroot}%{_datadir}/%{name}

# Generate man pages
mkdir -p %{buildroot}%{_mandir}/man1
help2man ./haxe --version-option=-version --no-discard-stderr --no-info --output=%{buildroot}%{_mandir}/man1/haxe.1
help2man ./haxelib --help-option=help --version-option=version --no-info --output=%{buildroot}%{_mandir}/man1/haxelib.1

%check
%{buildroot}%{_bindir}/haxe -version
%{buildroot}%{_bindir}/haxelib version

%files
%defattr(-,root,root)
%doc README.md extra/LICENSE.txt extra/CHANGES.txt extra/CONTRIB.txt
%{_bindir}/haxe
%{_bindir}/haxelib
%{_mandir}/man1/haxe.1*
%{_mandir}/man1/haxelib.1*
%{_datadir}/%{name}/

%changelog
* Fri Feb 23 2018 andy@onthewings.net
- Update to 3.4.7
  * Backward compatible to Haxe 3.4.5.
  * Fixed compiler cannot find std lib when executed by another
    program.
  * Fixed compiler failure for some output directories.
  * Bugfixes to php, as3 targets as well as code completion.
  * Detail available at https://github.com/HaxeFoundation/haxe/
    blob/3.4.7/extra/CHANGES.txt#L1-L18
* Mon Feb  5 2018 andy@onthewings.net
- Update to 3.4.5
  * Backward compatible to Haxe 3.4.4.
  * Bugfixes and improvements to php and js targets as well as dce.
  * Detail available at https://github.com/HaxeFoundation/haxe/
    blob/3.4.5/extra/CHANGES.txt#L1-L16
- Compile haxelib as a valid binary using `nekotools boot -c ...`.
* Mon Oct  9 2017 andy@onthewings.net
- Updated to 3.4.4
  * Backward compatible to Haxe 3.4.3.
  * Fix flash target broken when compiled with OCaml 4.05.
  * Detail available at https://github.com/HaxeFoundation/haxe/
    blob/3.4.4/extra/CHANGES.txt#L1-L8
* Mon Oct  2 2017 jengelh@inai.de
- Trim filler wording from description.
* Tue Sep 26 2017 andy@onthewings.net
- Updated to 3.4.3
  * Backward compatible to Haxe 3.4.2.
  * Various fixes, mostly related to php output.
  * Detail available at https://github.com/HaxeFoundation/haxe/
    blob/3.4.3/extra/CHANGES.txt#L1-L20
* Thu Mar 23 2017 andy@onthewings.net
- Updated to 3.4.2
  * Backward compatible to Haxe 3.4.0.
  * Improvements:
    + Various fixes in cpp and php7 output.
    + Added source maps generation for php7.
  * Detail available at https://github.com/HaxeFoundation/haxe/
    blob/3.4.2/extra/CHANGES.txt#L1-L35
* Sat Feb  4 2017 andy@onthewings.net
- Updated to 3.4.0
  * Backward compatible to Haxe 3.2.
  * Improvements and new features:
    + Three new targets: 1. HashLink, 2. Lua, 3. PHP7
    + Major improvements to compiler services for IDE support
    + Improved C++ output.
    + Improved static code analysis.
    + New language additions: Any, import.hx, @:structInit, etc.
  * Detail available at https://haxe.org/blog/haxe-3.4-release/
* Mon Nov 23 2015 andy@onthewings.net
- Updated to 3.2.1.
- Moved the haxe standard library files to _datadir.
- Generate man pages using help2man.
- Spec file clean-up.
  * Clarified license.
  * Manually cp files instead of using "make install".
  * Added BuildRoot as suggested in openSUSE specfile guidelines.
* Sun Jun  7 2015 pvince81@opensuse.org
- Fix haxelib shell script to properly pass arguments
* Sat May 16 2015 dap.darkness@gmail.com
- Updated to 4.2.0:
  * New features:
    + all: added @:noPrivateAccess to re-enable access
    restrictions within @:privateAccess
    + cpp: some support for @:nativeGen metadata
  * Bugfixes:
    + all: @:generic classes with constructor constraints detection
    + all: variable initialization check issue in loop condition
    + all: pattern matching on @:enum abstracts via field access
    + all: missing implicit casts in Map literals (#4100)
    + all: various minor issues in haxe.xml.Parser
    + all: class path issue when HAXE_STD_PATH is set (#4163)
    + js: DCE issue related to printing enums (#4197)
    + js: various issues with the new Bytes implementation
    + php: EOF handling in FileInput.readByte (#4082)
    + cs/java: Math.fround implementation (#4177)
    + cs/java: some cases of Std.parseInt failing (#4132)
    + cpp: compilation without -main (#4199)
  * General improvements and optimizations:
    + all: --macro keep no longer causes types to be included
    for compilation
    + php: support interpolation in php code
    + js: added variable number of arguments support
    in js.html.* classes
    + js: refined new HTML externs
  * Macro features and changes:
    + macro: [breaking] synced FClosure and FInstance
    with the compiler updates
- %%install section refactoring.
- general spec file clean-up.
* Sun May 10 2015 dap.darkness@gmail.com
- Added missing files to resolve builds issue.
- Fixed various warnings.
* Sat Jan 24 2015 prusnak@opensuse.org
- imported package from dmacvicar
- update to version 3.1.3
